{% if NEW_VERSION %}
    <div class="fixed-top position-relative h2 bg-warning text-primary text-center">THERE IS A NEW VERSION ({{NEW_VERSION}}) OF LOOPHOST AVAILABLE! YOU SHOULD 
    <a href="https://fling.dev/upgrade" class="stretched-link">UPGRADE NOW</a>
    </div>
{% endif %}